import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.io.*;
import com.jinsight.jetchart.*;


/**
 * This demo  generates   a  jpeg file   from  a  line chart. After  clicking  the  'save jpeg'
 * button,   a  jpeg file  is   created  in   the   current  directory.  Jpeg  file  generation 
 * is  useful  if   charts  are  generated  from  servlet requests. A jpeg image may be created
 * on the server-side by a servlet and sent back to the client browser.
 * For this application  to work properly, the file 'sEncoders.jar', found  in  the JetChart/lib/
 * Swing directory, must be included in the classpath.
 *
 * @author Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main extends JFrame implements ActionListener,Runnable {

    Graph graph;
    LineSerie ls;
    JButton jpg;
    JLabel message;

    // This class is found in the Encoders.jar file.
    ChartEncoder chartEncoder;

    /**
     * A File object is created here. The jpeg encoding process generates
     * a file in the application directory with the name linechart.jpg.
     */
    File imageFile=new File("linechart.jpg");

    public Main() {

	setTitle("The JetChart Library - Jpeg file generation");

	graph=new Graph();
       
	// Creates chart encoder. The chart encoder wraps a GIF, a PNG and a JPEG encoders.
	// To start encoding chart, some methods must be invoked on this object.  See  the 
	// run() method.
	chartEncoder=new ChartEncoder(graph);

	// Sets graphic context properties.
	setChartProperties();

	// Creates a line series and sets its properties.
	createLineSeries();
	
	// Adds the line series to the graphic context.
	graph.addSerie(ls);
	
        Container ct=getContentPane();
	ct.add("Center",graph);
	
	// Creates top panel with a jpeg generation button.
	createTopPanel();
	
	addWindowListener(new WindowAdapter() {
	    public void windowClosing(WindowEvent evt) {
		System.exit(0);
	    }
	});
	

	setSize(600,400);

	// Centers frame on the window
	Dimension d=getToolkit().getScreenSize();
	setLocation((d.width-getSize().width)/2,(d.height-getSize().height)/2);
	
	setVisible(true);
    }
    
    private void setChartProperties() {
	
        // Sets the chart gradient effect colors.
        graph.setGradientColors(new Color(255,255,191),Color.blue);

        // Changes the labels color to yellow.
        graph.getGraphSet(0).setLabelsColor(Color.yellow);

        // Disables automatic scale and sets a logarithmic scale.
        Scale scale=graph.getGraphSet(0).getScale();
        scale.setAutoScaleEnabled(false);
        scale.setLogEnabled(true);
        scale.setLogBase(10);
        scale.setMinValue(10);
        scale.setMaxValue(50000);

        // Loads an image to be displayed on the chart background.
        Image img=Toolkit.getDefaultToolkit().getImage("paper.jpg");

        // Sets the background image to be displayed tiled and within
        // the graph area.
        graph.setBackgroundImage(img,Graph.TILE);
        graph.setBackgroundImageArea(Graph.GRAPH_AREA);

        // Sets chart title and font.
	graph.setTitle(new String[]{"MarkSoftware Inc.","Sales Performance Graph"});
        graph.setTitleFont(new Font("SansSerif",Font.BOLD,12));

	// Sets labels for the horizontal axis.
	String[] labels={"1969","1974","1979","1984","1989","1994","1999"};
	graph.setLabels(labels);

        // Increases the start and end gaps. These gaps delimit the area where
        // the line series is painted.
        graph.setLabelsAxisStartGap(30);
        graph.setLabelsAxisEndGap(30);

        // Sets the format of values to be displayed in the series data points legends.
        graph.setValueFormat("###,###");
	
        // Enables grid and sets its style to dashed.
        Grid grid=graph.getGraphSet(0).getGrid();
        grid.setEnabled(true);
        grid.setStyle(Grid.DASHED);

    }
    
    private void createLineSeries() {

	double[] values={65,320,1240,6650,14400,22600,31423};
	
	// Creates a line  series
 	ls=new LineSerie(values,"Sales Evolution");
	ls.setColor(Color.red);
	ls.setThickness(2);
        // Enables legends on series data points.
        ls.setMarkLegendEnabled(true);
        ls.setMarkLegendOpacityEnabled(false);
	
    }

    private void createTopPanel() {
	JPanel topPanel=new JPanel();
	topPanel.setLayout(new FlowLayout(FlowLayout.LEFT));

	jpg=new JButton("Save jpg file");
	jpg.addActionListener(this);
	topPanel.add(jpg);

	message=new JLabel("Generating jpg file...");
	topPanel.add(message);
	message.setVisible(false);

        Container ct=getContentPane();
	ct.add("North",topPanel);

    }

    public void actionPerformed(ActionEvent evt) {

	message.setVisible(true);
	message.getParent().validate();

	/**
	 * Disables chart to prevent user interaction while generating jpg. 
	 */
	graph.setEnabled(false);

	jpg.setEnabled(false);
	
	Thread t=new Thread(this);
	t.start();
	
    }

    public void run() {

	/**
	 * Starts encoding process. Sets image quality to 85 pct.
	 */
	try {
	    chartEncoder.jpegEncode(imageFile,85);

	}
	catch (IOException e) {
	    e.printStackTrace();
	}
	finally {
	    // Enables chart.
	    graph.setEnabled(true);
	    message.setVisible(false);
	    jpg.setEnabled(true);
	}

    }

    public static void main(String[] args) {
	new Main();
    }

}
    
 
