import com.jinsight.jetchart.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * An example of a scrollable chart. The key  to  delimiting  a range  of data
 * points  and  scrollling  a  reduced  area is basically limited to correctly
 * setting the values to be passed  to  the Graph.setDataSetRange  method  and
 * to the constructor of a scrolling bar object, like Scrollbar, for  example.
 * This  demo  pertains  to AWT classes,  so it is using the Scrollbar class.
 * The visible range is limited to 20 data points.
 * @author Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main extends JFrame implements AdjustmentListener {

    JScrollBar scrollBar;

    Graph graph;

    double[]  values;

    public Main() {

	setTitle("The JetChart Library - A Scrollable Chart Demo");

	addWindowListener(new WindowAdapter() {
		public void windowClosing(WindowEvent evt) {
		    System.exit(0);
		}
	    });
	
	// Creates the chart context.
	graph=new Graph();

	graph.setTitle(new String[]{"The JetChart Library",
				    "A Scrollable Chart Demo"});

	graph.set3DEnabled(true);

	// Enables the grid and crossed grid lines of the primary GraphSet object.
	// See JetChart documentation about the GraphSet class for further details.
	Grid grid=graph.getGraphSet(0).getGrid();
	grid.setEnabled(true);
	GridCrossedLines gridCrossedLines=graph.getGraphSet(0).getGridCrossedLines();
	gridCrossedLines.setEnabled(true);
	gridCrossedLines.setColor(Color.cyan);

	// Enables the right y axis.
	Scale scale=graph.getGraphSet(0).getScale();
	scale.setPosition(Scale.LEFT_RIGHT);

	// Disables automatic scale and set increment and max values.
	scale.setAutoScaleEnabled(false);
	scale.setMaxValue(150);
	scale.setIncrement(20);

	graph.getToolTip().setEnabled(true);
	
	// Displays an image on the background.
        graph.setBackgroundImage(getToolkit().getImage("wood.jpg"),Graph.TILE);

	graph.setStartDate("07012001");

	// Delimits the range of data points to be painted, out of the whole set.
	// The first time chart is painted the only visible points will be those
	// having indexes ranging from 0 to 19.
	graph.setDataSetRange(0,19);

	// Values for the line series.
	values=new double[]{131.90,132.80,130.50,131.00,136.75,135.00,131.50,130.50,
			    132.40,133.30,130.90,123.40,122.25,118.00,120.00,116.10,
			    115.00,103.45,107.50,103.80,99.00,96.75,94.00,95.90,97.50,
			    98.40,100.20,102.00,110.40,104.50,108.70,107.75,107.45,
			    103.00,100.90,99.25,93.80,99.25,103.00,100.25,102.70,
			    107.15,106.00,107.15,109.00,104.00,96.50,97.95,99.70,
			    97.70,91.00,87.45,86.80,88.60,85.40,85.90,84.85,
			    76.55, 68.00,67.45,61.90,60.90,60.75,53.60,58.50,
			    57.20,51.25,48.50,45.75,46.90,52.55,51.40,54.00,
			    51.70,41.20,38.75,34.00,33.50,33.25,34.25,33.90,
			    30.00,33.50,34.95,31.45,26.95,28.40,30.90,28.90,
			    29.90,29.80,33.25,34.50,34.00,36.90,37.00,36.40,
			    34.70,37.50,38.30,39.40,43.50,45.80,48.70,46.45};

	// Creates a scroll bar and adds it to the bottom area. The scroll bar visible
	// amount is the number of visible data points, as set above using the 
	// setDataSetRange method. Using a Scrollbar object requires that the maximum 
	// value be always set to the maximum index available plus 1, which is the
	// length of the values array, in this specific case.
	scrollBar=new JScrollBar(JScrollBar.HORIZONTAL,0,20,0,values.length);
	scrollBar.addAdjustmentListener(this);

	Panel bottomPanel=new Panel(new BorderLayout());

	bottomPanel.add(scrollBar,BorderLayout.CENTER);

        Container ct=getContentPane();

	ct.add("South",bottomPanel);

	// Creates a line series.
	LineSerie ls=new LineSerie(values,"Line Series");
	ls.setColor(Color.red);
	ls.setThickness(2);
	
	// Adds the line series to the chart context.
	graph.addSerie(ls);

	// Adds the scroll pane to the container.
	ct.add(graph,BorderLayout.CENTER);

	setSize(600,400);

	setVisible(true);

    }

    public void adjustmentValueChanged(AdjustmentEvent evt) {

	// Adjusts data points delimiters to reflect the range
	// selected with the scrolling bar.
	graph.setDataSetRange(evt.getValue(),evt.getValue()+19);
	graph.repaint();
    }
    
    public static void main(String[] args) {
	new Main();
    }
} 
	
