import com.jinsight.jetchart.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.util.Vector;
import java.io.*;

/**
 * A target  zone is a  color  filled polygon  horizontally  or  vertically  painted  across
 * the chart area.  The goal  of  a target  zone is to  set upper and lower  limits  between
 * which  a  sequence of  data points  can  be  plotted  and   compared  against   delimiter
 * values. In this  application  we  can  see the  results  of an  assessment  test  applied 
 * to three individuals. The  results are plotted against the target zone, which  represents
 * an area in which values are considered to be within a normal range. 
 * Each  individual values  are read from separate xml files, which are located in  the same
 * directory  where  this application  can  be found. This is a Swing application, hence  it 
 * requires  that the Swing  compatible 'sGraphChart.jar' file be included in the  classpath.
 * The 'sGraphChart.jar' file can be found in the JetChart/lib directory after decompression
 * of the JetChart package.
 * @author Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main extends JFrame implements ItemListener {

    LineSerie ls;
    Graph graph;
    
    public Main() {
	
	setTitle("The JetChart Library - Target Zone demo");

        createTopPanel();

        createChartContext();

        setGridProperties();

        createLineSeries();

	createTargetZone();

        setScaleProperties();

	addWindowListener(new WindowAdapter() {
		public void windowClosing(WindowEvent evt) {
		    System.exit(0);
		}
	    });
			  

	setSize(600,450);

	setVisible(true);

    }

    public void itemStateChanged(ItemEvent evt) {

	JComboBox cb=(JComboBox)evt.getSource();

	int choice=cb.getSelectedIndex();

	FileReader fr=null;

        // Reads the xml file that corresponds to the selected item.
	try {
	    switch (choice) {
	    case 0:
		ls.setValues(null);
		break;
	    case 1:
		fr=new FileReader("chart1.xml");
		graph.readXMLData(fr);
		break;
	    case 2:
		fr=new FileReader("chart2.xml");
		graph.readXMLData(fr);
		break;
	    case 3:
		fr=new FileReader("chart3.xml");
		graph.readXMLData(fr);
		break;
	    }
	}
	catch (IOException e) {
	    e.printStackTrace();
	}
	finally {
	    if (fr!=null) {
		try {
		    fr.close();
		}
		catch (IOException e) {
		}
	    }
	}
	
        // Sets the series title. It is the text of the selected item,
        // which is displayed above the top of the vertical axis.
	ls.setTitle((String)cb.getSelectedItem());

	graph.repaint();
	
    }

    private void createChartContext() {

        graph=new Graph();
	graph.setLabelsFont(new Font("Helvetica",Font.PLAIN,12));
	graph.setVerticalLabelsEnabled(true);
	graph.setTitle(new String[]{"Human Resource Profile","Individual Assessment"});
	graph.setTitleFont(new Font("SansSerif",Font.BOLD,14));

        // The target zone and the line series must start on the vertical axis, ending
        // at the rightmost point of the horizontal axis. The methods below disable
        // the gaps that are, by default, horizontally inserted at the beginning and
        // at the end of the chart area.
	graph.setLabelsAxisStartGap(0);
	graph.setLabelsAxisEndGap(0);

	graph.setGradientColors(Color.white,new Color(51,102,255));

        Container ct=getContentPane();

        ct.add("Center",graph);
 
    }

    private void setGridProperties() {

        // Enables the horizontal and vertical grid lines.

        GraphSet graphSet=graph.getGraphSet(0);
        Grid grid=graphSet.getGrid();
	grid.setColor(Color.gray);
	grid.setEnabled(true);

	GridCrossedLines gc=graphSet.getGridCrossedLines();
	gc.setColor(Color.gray);
	gc.setEnabled(true);

    }

    private void createLineSeries() {

       ls=new LineSerie();

       // The series id is checked by the xml parser in order to identify
       // the series that will  be assigned the values read from the xml
       // file.
       ls.setId(0);

       // The series title is positioned above and to the right of the top
       // of the left vertical axis.
       ls.setTitlePosition(GraphSerie.ABOVE_TOP_YAXIS);
       ls.setTitleFont(new Font("SansSerif",Font.BOLD,14));

       ls.setColor(Color.red);

       // The squares positioned on each data point coordinates are called
       // 'marks'. The marks are colored in red.
       ls.setMarksColor(Color.red);

       graph.addSerie(ls);

    }

    private void createTargetZone() {

        // Sets the lower and upper values and assigns them to the TargetZone object.
       	double[] lowerValues=new double[]{28,28,30,28,25,28,29,25,27,28,28,30,27,32};
	double[] upperValues=new double[]{32,32,35,32,29,33,32,29,31,32,32,34,31,37};
	TargetZone tz=new TargetZone(lowerValues,upperValues);
	tz.setColor(Color.cyan);

        GraphSet graphSet=graph.getGraphSet(0);

        // Adds the TargetZone object to the primary GraphSet.
	graphSet.addTargetZone(tz);
  
    }
  
    private void setScaleProperties() {

       // Disables the automatic scale and sets its maximum, minimum and
       // increment values. Decimal places are not displayed.
       GraphSet graphSet=graph.getGraphSet(0);
       Scale scale=graphSet.getScale();
       scale.setAutoScaleEnabled(false);
       scale.setValueFormat("###");
       scale.setMaxValue(40);
       scale.setMinValue(8);
       scale.setIncrement(2);

    }

    private void createTopPanel() {

	JPanel topPanel=new JPanel(new FlowLayout(FlowLayout.LEFT));

	Vector data=new Vector();
	data.addElement("Select an individual");
	data.addElement("Richard Norton");
	data.addElement("Michael Andretti");
	data.addElement("Ann Murray");

	JComboBox jc=new JComboBox(data);
	jc.addItemListener(this);

	topPanel.add(jc);

	Container ct=getContentPane();

	ct.add("North",topPanel);

    } 

    public static void main(String[] args) {
	new Main();
    }
}
